@@ -27,7 +27,7 @@ def create_project(args: Namespace, asws: dict):
 
     answers.settings["default"]["DEBUG"] = False
     answers.settings["development"]["DEBUG"] = True
-    answers.secrets["default"]["SECRET_KEY"] = os.urandom(32)
+    answers.secrets["default"]["SECRET_KEY"] = str(os.urandom(32))
 
     app_type_handler(answers)
     database_handler(answers)
